#!/bin/sh

die() {
    echo $* >&2
    exit 1
}

set -e

BUILD_DIR=/var/lib/catalyst/store/builds/default
RELEASE_BASE_URI=https://gentoo.osuosl.org/releases

if [ ! -r ${BUILD_DIR}/stage3-amd64-latest.tar.xz ] \
  && [ ! -r ${BUILD_DIR}/stage3-amd64-latest.tar.bz2 ]
then
    # Get latest stage3 tag
    STAGE3_TAG=$(wget -q -O - \
        ${RELEASE_BASE_URI}/amd64/autobuilds/latest-stage3-amd64.txt \
        | grep -v "^#" | cut -d ' ' -f 1)

    # Download latest stable stage3 build
    for SUFFIX in "" ".CONTENTS" ".DIGESTS"; do
        wget -q -N -P ${BUILD_DIR} \
            ${RELEASE_BASE_URI}/amd64/autobuilds/${STAGE3_TAG}${SUFFIX}

        ln -sf  "${BUILDDIR}/$(basename ${STAGE3_TAG})${SUFFIX}" \
            "${BUILDDIR}/stage3-amd64-latest.tar.xz${SUFFIX}"
    done
fi

# Download latest portage snapshot
wget -q -N -P /var/lib/catalyst/store/snapshots/ \
    ${RELEASE_BASE_URI}/snapshots/current/portage-latest.tar.bz2

# Build stage1 snapshot
catalyst -c /catalyst.conf -f /stage1.spec -p $*

# Build stage2 snapshot
catalyst -c /catalyst.conf -f /stage2.spec -p $*

# Build stage3 snapshot
catalyst -c /catalyst.conf -f /stage3.spec -p $*

# Build custom packages
catalyst -c /var/lib/catalyst/catalyst.conf -f /var/lib/catalyst/stage4.spec $*
